@@ -1,42 +1,67 @@
 multigraph <-
 function (net, layout = c("circ", "force", "stress", "conc", 
-    "rand"), scope, directed = TRUE, main = NULL, seed = NULL, 
+    "rand"), scope, directed = TRUE, main = NULL, lbs, seed = NULL, 
     maxiter = 100, alpha = c(1, 1, 1), collRecip, showLbs, showAtts, 
-    weighted, cex.main, coord, clu, cex, lwd, pch, lty, bwd, 
-    tcol, tcex, att, bg, mar, pos, asp, ecol, vcol, vcol0, hds, 
-    vedist, rot, mirrorX, mirrorY, col, lbat, drp, swp, loops, 
-    swp2, signed, scl, add, mirrorD, mirrorL, ...) 
+    cex.main, weighted, weights, coord, clu, cex, lwd, pch, lty, 
+    bwd, fcol, att, bg, mar, pos, asp, ecol, vcol, vcol0, cex2, 
+    fsize2, fcol2, hds, vedist, rot, mirrorX, mirrorY, col, lbat, 
+    drp, loops, swp, swp2, signed, scl, add, mirrorD, mirrorL, 
+    opt, mirrorV, mirrorH, ffamily, fstyle, fsize, ...) 
 {
-    if (isTRUE(is.list(net) == TRUE) == TRUE && isTRUE(attr(net, 
-        "class") == "Signed") == FALSE) {
-        net <- multiplex::transf(net, type = "toarray", lb2lb = TRUE)
+    flgmlvl <- FALSE
+    if (isTRUE(attr(net, "class") == "Multilevel") == TRUE) {
+        flgmlvl <- TRUE
+        mlvl <- net
+        net <- mlvl$bmat
+        ifelse(missing(pch) == TRUE, pch <- c(rep(1, length(mlvl$lbs$dm)), 
+            rep(0, length(mlvl$lbs$cdm))), NA)
     }
-    else if (isTRUE(is.vector(net) == TRUE) == TRUE) {
-        ifelse(missing(add) == FALSE && isTRUE(is.vector(add) == 
-            TRUE) == TRUE, net <- multiplex::transf(net, type = "toarray", 
-            lb2lb = TRUE, lbs = sort(unique(multiplex::dhc(c(net, 
-                add))))), net <- multiplex::trnf(net, tolist = FALSE, 
-            lb2lb = TRUE))
-    }
-    else if (isTRUE(is.null(net) == TRUE) == TRUE && (missing(add) == 
-        FALSE && isTRUE(is.vector(add) == TRUE) == TRUE)) {
-        net <- matrix(0L, nrow = length(add), ncol = length(add), 
-            dimnames = list(add, add))
+    else if (isTRUE(attr(net, "class") == "Data.Set") == TRUE) {
+        att <- net$net[, , which(net$atnet[[1]] == 1)]
+        net <- net$net[, , which(net$atnet[[1]] == 0)]
     }
     else {
         NA
     }
+    if (isTRUE(is.data.frame(net) == TRUE) == FALSE) {
+        if (isTRUE(is.list(net) == TRUE) == TRUE && isTRUE(attr(net, 
+            "class") == "Signed") == FALSE) {
+            net <- multiplex::transf(net, type = "toarray", lb2lb = TRUE, 
+                lbs = sort(unique(multiplex::dhc(unlist(net)))))
+        }
+        else if (isTRUE(is.vector(net) == TRUE) == TRUE) {
+            ifelse(missing(add) == FALSE && isTRUE(is.vector(add) == 
+                TRUE) == TRUE, net <- multiplex::transf(net, 
+                type = "toarray", lb2lb = TRUE, lbs = sort(unique(multiplex::dhc(c(net, 
+                  add))))), net <- multiplex::trnf(net, tolist = FALSE, 
+                lb2lb = TRUE))
+        }
+        else if (isTRUE(is.null(net) == TRUE) == TRUE && (missing(add) == 
+            FALSE && isTRUE(is.vector(add) == TRUE) == TRUE)) {
+            net <- matrix(0L, nrow = length(add), ncol = length(add), 
+                dimnames = list(add, add))
+        }
+        else {
+            NA
+        }
+    }
+    else {
+        net <- as.matrix(net)
+    }
     ifelse(missing(signed) == FALSE && isTRUE(signed == TRUE) == 
         TRUE, signed <- TRUE, signed <- FALSE)
-    if (isTRUE(is.array(net) == TRUE) == FALSE && isTRUE(signed == 
-        TRUE) == FALSE && missing(scope) == TRUE) 
-        stop("\"net\" should be an array.")
     ifelse(isTRUE(dim(net)[3] == 1) == TRUE, net <- net[, , 1], 
         NA)
     ifelse(missing(weighted) == FALSE && isTRUE(weighted == TRUE) == 
         TRUE, weighted <- TRUE, weighted <- FALSE)
+    ifelse(missing(weights) == FALSE && isTRUE(weights == TRUE) == 
+        TRUE, weights <- TRUE, weights <- FALSE)
     ifelse(missing(loops) == FALSE && isTRUE(loops == TRUE) == 
         TRUE, loops <- TRUE, loops <- FALSE)
+    ifelse(missing(mirrorH) == FALSE && isTRUE(mirrorH == TRUE) == 
+        TRUE, mirrorY <- TRUE, NA)
+    ifelse(missing(mirrorV) == FALSE && isTRUE(mirrorV == TRUE) == 
+        TRUE, mirrorX <- TRUE, NA)
     if (missing(scope) == FALSE && isTRUE(any(attr(scope, "names") == 
         "directed") == TRUE) == TRUE) {
         if (isTRUE(scope[[which(attr(scope, "names") == "directed")]] == 
@@ -155,11 +180,30 @@ function (net, layout = c("circ", "force", "stress", "conc",
     }
     ifelse(missing(asp) == TRUE, asp <- 1, NA)
     ifelse(missing(lwd) == TRUE, lwd <- 1, NA)
+    if (isTRUE(flgmlvl == TRUE) == TRUE) {
+        ifelse(missing(pch) == FALSE && isTRUE(length(pch) == 
+            2) == TRUE, pch <- c(rep(pch[1], length(mlvl$lbs$dm)), 
+            rep(pch[2], length(mlvl$lbs$cdm))), NA)
+        ifelse(missing(ecol) == FALSE && isTRUE(length(ecol) == 
+            2) == TRUE, ecol <- c(rep(ecol[1], length(which(mlvl$modes == 
+            "1M"))), rep(ecol[2], length(which(mlvl$modes == 
+            "2M")))), NA)
+    }
+    else {
+        NA
+    }
     ifelse(missing(pch) == TRUE, pch <- 21, NA)
-    ifelse(missing(tcol) == TRUE, tcol <- 1, NA)
+    ifelse(missing(fcol) == TRUE, fcol <- 1, NA)
     ifelse(missing(bwd) == TRUE, bwd <- 1, NA)
     ifelse(isTRUE(bwd < 0L) == TRUE, bwd <- 0L, NA)
-    ifelse(missing(bg) == TRUE, bg <- graphics::par()$bg, NA)
+    if (missing(bg) == TRUE) {
+        bg <- graphics::par()$bg
+        flgbg <- FALSE
+    }
+    else {
+        obg <- graphics::par()$bg
+        flgbg <- TRUE
+    }
     ifelse(missing(cex.main) == TRUE, cex.main <- graphics::par()$cex.main, 
         NA)
     ifelse(missing(rot) == TRUE, NA, rot <- rot[1] * -1)
@@ -182,21 +226,20 @@ function (net, layout = c("circ", "force", "stress", "conc",
         else if (isTRUE(hds == 0L) == TRUE) {
             hds <- 0.01
         }
-        else {
-            NA
-        }
     }
     else {
         ifelse(missing(scl) == TRUE, hds <- 1L, hds <- 1L * scl)
     }
-    ifelse(isTRUE(dim(net)[1] > 8) == TRUE, hds <- hds * 0.75, 
-        NA)
+    ifelse(isTRUE(dim(net)[1] > 8) == TRUE || isTRUE(weighted == 
+        TRUE) == TRUE || isTRUE(flgmlvl == TRUE) == TRUE, hds <- hds * 
+        0.75, NA)
     ifelse(missing(scl) == TRUE, scl <- rep(1, 2), NA)
     ifelse(isTRUE(length(scl) == 1) == TRUE, scl <- rep(scl, 
         2), scl <- scl[1:2])
     ifelse(missing(vedist) == TRUE, vedist <- 0, NA)
     ifelse(isTRUE(vedist > 1L) == TRUE, vedist <- 1L, NA)
-    if (isTRUE(signed == TRUE) == TRUE) {
+    if (isTRUE(signed == TRUE) == TRUE || isTRUE(attr(net, "class") == 
+        "Signed") == TRUE) {
         if (isTRUE(attr(net, "class") == "Signed") == TRUE) {
             if (any(net$val %in% c(-1, 0, 1)) == TRUE) {
                 net <- multiplex::zbind(multiplex::dichot(net$s, 
@@ -206,16 +249,16 @@ function (net, layout = c("circ", "force", "stress", "conc",
                 nets <- multiplex::zbnd(net$s, net$s)
                 net <- array(NA, dim = c(dim(nets)[1], dim(nets)[2], 
                   2), dimnames = list(dimnames(net$s)[[1]], dimnames(net$s)[[1]]))
-                net <- replace(net, nets == "o", 0)
-                net <- replace(net, nets == "a", 1)
+                net <- replace(net, nets == "o", 0L)
+                net <- replace(net, nets == "a", 1L)
                 net[, , 1] <- replace(net[, , 1], nets[, , 1] == 
-                  "p", 1)
+                  "p", 1L)
                 net[, , 1] <- replace(net[, , 1], nets[, , 1] == 
-                  "n", 0)
+                  "n", 0L)
                 net[, , 2] <- replace(net[, , 2], nets[, , 2] == 
-                  "n", 1)
+                  "n", 1L)
                 net[, , 2] <- replace(net[, , 2], nets[, , 2] == 
-                  "p", 0)
+                  "p", 0L)
                 rm(nets)
             }
         }
@@ -223,11 +266,21 @@ function (net, layout = c("circ", "force", "stress", "conc",
             ifelse(isTRUE(is.na(dim(net)[3]) == TRUE) == TRUE, 
                 NA, net <- net[, , seq_len(2)])
         }
-        ifelse(is.null(dimnames(net)[[1]]) == TRUE & isTRUE(showLbs == 
+        ifelse(is.null(dimnames(net)[[1]]) == TRUE | isTRUE(showLbs == 
             FALSE) == TRUE, showLbs <- FALSE, showLbs <- TRUE)
     }
-    ifelse(is.null(dimnames(net)[[1]]) == TRUE, lbs <- as.character(seq_len(dim(net)[1])), 
-        lbs <- dimnames(net)[[1]])
+    else {
+        net <- replace(net, net == Inf, 0L)
+    }
+    if (isTRUE(attr(net, "class") == "Signed") == FALSE) {
+        if (missing(lbs) == FALSE) {
+            NA
+        }
+        else {
+            ifelse(is.null(dimnames(net)[[1]]) == TRUE, lbs <- as.character(seq_len(dim(net)[1])), 
+                lbs <- dimnames(net)[[1]])
+        }
+    }
     n <- dim(net)[1]
     ifelse(isTRUE(is.na(dim(net)[3]) == TRUE) == TRUE, z <- 1L, 
         z <- dim(net)[3])
@@ -308,6 +361,10 @@ function (net, layout = c("circ", "force", "stress", "conc",
             2), ecol <- grDevices::gray.colors(r, start = 0.1, 
             end = 0.5))
     }
+    else {
+        ifelse(isTRUE(ecol == 0) == TRUE, ecol <- "#FFFFFF", 
+            NA)
+    }
     if (isTRUE(weighted == TRUE) == TRUE) {
         ifelse(missing(lty) == TRUE, lty <- rep(1, r), lty <- rep(lty, 
             r))
@@ -423,12 +480,12 @@ function (net, layout = c("circ", "force", "stress", "conc",
     else {
         NA
     }
-    if (missing(tcex) == TRUE) {
-        ifelse(isTRUE(max(cex) < 2) == TRUE, tcex <- cex * 0.66, 
-            tcex <- cex * 0.33)
+    if (missing(fsize) == TRUE) {
+        ifelse(isTRUE(max(cex) < 2) == TRUE, fsize <- cex * 0.66, 
+            fsize <- cex * 0.25)
     }
     else {
-        NA
+        fsize <- fsize/10
     }
     ifelse(isTRUE(weighted == FALSE) == TRUE && isTRUE(bwd > 
         1L) == TRUE, bwd <- 1L, NA)
@@ -477,7 +534,7 @@ function (net, layout = c("circ", "force", "stress", "conc",
         vcol[which(vcol == 0)] <- graphics::par()$bg
     }
     if (isTRUE(any(pch %in% 21:25)) == TRUE) {
-        if (missing(vcol0) == TRUE) {
+        if (missing(vcol0) == TRUE || isTRUE(vcol0 == 0) == TRUE) {
             vcol0 <- vcol
         }
         else {
@@ -505,10 +562,19 @@ function (net, layout = c("circ", "force", "stress", "conc",
     else {
         vcol0 <- vcol
     }
-    ifelse(isTRUE(n > 20) == TRUE, ffds <- 0.2, ffds <- 0)
-    ifelse(isTRUE(directed == TRUE) == TRUE, fds <- 130L - (n * 
-        ffds), fds <- 140L - (n * ffds))
-    if (isTRUE(flgcx == TRUE) == TRUE) {
+    if (isTRUE(n > 20) == TRUE) {
+        ffds <- 0.2
+    }
+    else if (isTRUE(n == 2) == TRUE) {
+        ffds <- -5
+    }
+    else {
+        ffds <- 0
+    }
+    ifelse(isTRUE(directed == TRUE) == TRUE, fds <- 120L - (n * 
+        ffds), fds <- 145L - (n * ffds))
+    if (isTRUE(flgcx == TRUE) == TRUE || (isTRUE(flgcx == FALSE) == 
+        TRUE && isTRUE(cex > 5) == TRUE)) {
         fds <- fds - 10L
     }
     else if (isTRUE(flgcx == FALSE) == TRUE) {
@@ -602,11 +668,13 @@ function (net, layout = c("circ", "force", "stress", "conc",
             stop("Invalid \"pos\" value.")
     }
     ifelse(missing(mirrorX) == FALSE && isTRUE(mirrorX == TRUE) == 
-        TRUE, crd[, 1] <- crd[, 1] * cos(pi) - crd[, 2] * sin(pi), 
-        mirrorX <- FALSE)
+        TRUE || missing(mirrorV) == FALSE && isTRUE(mirrorV == 
+        TRUE) == TRUE, crd[, 1] <- crd[, 1] * cos(pi) - crd[, 
+        2] * sin(pi), mirrorX <- FALSE)
     ifelse(missing(mirrorY) == FALSE && isTRUE(mirrorY == TRUE) == 
-        TRUE, crd[, 2] <- crd[, 2] * cos(pi) - crd[, 1] * sin(pi), 
-        mirrorY <- FALSE)
+        TRUE || missing(mirrorH) == FALSE && isTRUE(mirrorH == 
+        TRUE) == TRUE, crd[, 2] <- crd[, 2] * cos(pi) - crd[, 
+        1] * sin(pi), mirrorY <- FALSE)
     if (match.arg(layout) == "circ" && isTRUE(flgcrd == FALSE) == 
         TRUE) {
         if (isTRUE(mirrorX == TRUE) == TRUE && isTRUE(length(pos) == 
@@ -682,13 +750,14 @@ function (net, layout = c("circ", "force", "stress", "conc",
     nds <- ((2L/max(nds * (0.75))) * (nds * 0.75)) * (0.5)
     mscl <- mean(scl)
     cex <- cex * mscl
-    tcex <- tcex * mscl
-    opm <- graphics::par()$mar
+    fsize <- fsize * mscl
+    omr <- graphics::par()$mar
+    omi <- graphics::par()$mai
     if (missing(mar) == TRUE) {
-        mar <- rep(0, 4)
+        mar <- c(0, 0, 0, 0)
     }
     else {
-        NA
+        mar <- omr
     }
     ifelse(is.null(main) == TRUE, graphics::par(mar = mar), graphics::par(mar = mar + 
         c(0, 0, cex.main, 0)))
@@ -712,9 +781,13 @@ function (net, layout = c("circ", "force", "stress", "conc",
         xlim <- c(min(nds[, 1]) - ((cex[1])/200L), max(nds[, 
             1]) + ((cex[1])/200L))
     }
-    graphics::plot(nds, type = "n", axes = FALSE, xlab = "", 
-        ylab = "", ylim = ylim, xlim = xlim, asp = asp, main = main, 
-        cex.main = cex.main)
+    if (missing(opt) == FALSE && isTRUE(opt == TRUE) == TRUE) {
+        xlim <- xlim + c(-0.1, 0.1)
+        ylim <- ylim + c(0, 0.1)
+    }
+    suppressWarnings(graphics::plot(nds, type = "n", axes = FALSE, 
+        xlab = "", ylab = "", ylim = ylim, xlim = xlim, asp = asp, 
+        main = main, cex.main = cex.main, ...))
     tlbs <- vector()
     if (isTRUE(length(bds) > 0) == TRUE) {
         for (i in seq_len(length(attr(bds, "names")))) {
@@ -766,6 +839,12 @@ function (net, layout = c("circ", "force", "stress", "conc",
     else {
         flgcr <- rep(0L, z)
     }
+    if (isTRUE(weights == TRUE) == TRUE) {
+        mdp <- data.frame(matrix(nrow = 0L, ncol = 3L))
+    }
+    else {
+        NA
+    }
     if (isTRUE(length(tlbs) > 0) == TRUE) {
         for (k in seq_len(length(tlbs))) {
             prs <- as.numeric(multiplex::dhc(bds[[k]]))
@@ -954,6 +1033,41 @@ function (net, layout = c("circ", "force", "stress", "conc",
                     directed, bw, alfa, fds, flgcx, weighted, 
                     flgcr, hds, n))
                 }
+                if (isTRUE(weights == TRUE) == TRUE) {
+                  if (isTRUE(z == 1L) == TRUE) {
+                    ifelse(isTRUE(isSymmetric(net) == TRUE) == 
+                      TRUE, fsym <- 2L, fsym <- 1L)
+                    ifelse(isTRUE(directed == FALSE) == TRUE, 
+                      mdp[nrow(mdp) + 1, ] <- c((pars[1, 1] + 
+                        pars[2, 1])/2L, (pars[1, 2] + pars[2, 
+                        2])/2L, as.numeric(net[as.numeric(multiplex::dhc(bds[[k]])[1]), 
+                        as.numeric(multiplex::dhc(bds[[k]])[2])]/fsym + 
+                        net[as.numeric(multiplex::dhc(bds[[k]])[2]), 
+                          as.numeric(multiplex::dhc(bds[[k]])[1])]/fsym)), 
+                      mdp[nrow(mdp) + 1, ] <- c((pars[1, 1] + 
+                        pars[2, 1])/2L, (pars[1, 2] + pars[2, 
+                        2])/2L, as.numeric(net[as.numeric(multiplex::dhc(bds[[k]])[1]), 
+                        as.numeric(multiplex::dhc(bds[[k]])[2])]) + 
+                        net[as.numeric(multiplex::dhc(bds[[k]])[2]), 
+                          as.numeric(multiplex::dhc(bds[[k]])[1])]))
+                  }
+                  else {
+                    mpnet <- multiplex::mnplx(net, dichot = FALSE, 
+                      directed = TRUE)
+                    ifelse(isTRUE(directed == FALSE) == TRUE, 
+                      mdp[nrow(mdp) + 1, ] <- c((pars[1, 1] + 
+                        pars[2, 1])/2L, (pars[1, 2] + pars[2, 
+                        2])/2L, as.numeric(mpnet[as.numeric(multiplex::dhc(bds[[k]])[1]), 
+                        as.numeric(multiplex::dhc(bds[[k]])[2])] + 
+                        mpnet[as.numeric(multiplex::dhc(bds[[k]])[2]), 
+                          as.numeric(multiplex::dhc(bds[[k]])[1])])), 
+                      mdp[nrow(mdp) + 1, ] <- c((pars[1, 1] + 
+                        pars[2, 1])/2L, (pars[1, 2] + pars[2, 
+                        2])/2L, multiplex::mnplx(netdrp, dichot = FALSE, 
+                        directed = FALSE)[as.numeric(multiplex::dhc(bds[[k]])[1]), 
+                        as.numeric(multiplex::dhc(bds[[k]])[2])]))
+                  }
+                }
             }
             else {
                 NA
@@ -1046,47 +1160,201 @@ function (net, layout = c("circ", "force", "stress", "conc",
     else {
         NA
     }
+    if (isTRUE(weights == TRUE) == TRUE) {
+        mdps <- mdp[, 1:2]
+        mdps[, 1] <- mdps[, 1] * scl[1]
+        mdps[, 2] <- mdps[, 2] * scl[2]
+        ifelse(missing(fsize2) == TRUE, fsize2 <- fsize, fsize2 <- fsize2/10L)
+        ifelse(missing(cex2) == TRUE, cex2 <- fsize2, NA)
+        ifelse(missing(fcol2) == TRUE, fcol2 <- "#000000", NA)
+        if (isTRUE(flgbg == TRUE) == TRUE) {
+            graphics::points(mdps[, 1], mdps[, 2], pch = 16, 
+                cex = fsize2 * 2, col = bg, bg = bg)
+        }
+        else if (isTRUE(flgbg == FALSE) == TRUE) {
+            graphics::points(mdps[, 1], mdps[, 2], pch = 16, 
+                cex = fsize2 * 2, col = "#FFFFFF", bg = obg)
+        }
+        else {
+            NA
+        }
+        if (isTRUE(directed == FALSE) == TRUE) {
+            for (k in seq_along(tlbs)) {
+                graphics::text(mdps[k, ], labels = mdp[k, 3], 
+                  cex = fsize2, col = fcol2)
+            }
+            rm(k)
+        }
+        else {
+            for (k in seq_along(tlbs)) {
+                graphics::text(mdps[k, ], labels = mdp[k, 3], 
+                  cex = fsize2, col = fcol2)
+            }
+            rm(k)
+        }
+    }
     if (all(pch %in% 21:25) == TRUE) {
-        suppressWarnings(graphics::points(nds[, 1] * scl[1], 
-            nds[, 2] * scl[2], pch = pch, cex = cex, col = grDevices::adjustcolor(vcol0, 
+        graphics::points(nds[, 1] * scl[1], nds[, 2] * scl[2], 
+            pch = pch, cex = cex, col = grDevices::adjustcolor(vcol0, 
                 alpha = alpha[1]), bg = grDevices::adjustcolor(vcol, 
-                alpha = alpha[1])))
+                alpha = alpha[1]))
     }
     else {
-        suppressWarnings(graphics::points(nds[, 1] * scl[1], 
-            nds[, 2] * scl[2], pch = pch, cex = cex, col = grDevices::adjustcolor(vcol, 
+        graphics::points(nds[, 1] * scl[1], nds[, 2] * scl[2], 
+            pch = pch, cex = cex, col = grDevices::adjustcolor(vcol, 
                 alpha = alpha[1]), bg = grDevices::adjustcolor(vcol, 
-                alpha = alpha[1])))
+                alpha = alpha[1]))
     }
     if (isTRUE(showLbs == TRUE) == TRUE) {
         ndss <- nds
         ndss[, 1] <- ndss[, 1] * scl[1]
         ndss[, 2] <- ndss[, 2] * scl[2]
+        ifelse(missing(ffamily) == FALSE && isTRUE(ffamily %in% 
+            names(grDevices::postscriptFonts())) == TRUE, graphics::par(family = ffamily), 
+            NA)
         if (isTRUE(length(pos) == 1) == TRUE) {
             if (isTRUE(pos == 0) == TRUE) {
-                graphics::text(ndss, labels = lbs, cex = tcex, 
-                  adj = 0.5, col = tcol)
+                if (missing(fstyle) == TRUE || (missing(fstyle) == 
+                  FALSE && isTRUE(fstyle %in% c("italic", "bold", 
+                  "bolditalic") == FALSE))) {
+                  graphics::text(ndss, labels = lbs, cex = fsize, 
+                    adj = 0.5, col = fcol)
+                }
+                else if (missing(fstyle) == FALSE) {
+                  if (isTRUE(fstyle == "italic") == TRUE) {
+                    graphics::text(ndss, labels = as.expression(lapply(lbs, 
+                      function(x) bquote(italic(.(x))))), cex = fsize, 
+                      adj = 0.5, col = fcol)
+                  }
+                  else if (isTRUE(fstyle == "bold") == TRUE) {
+                    graphics::text(ndss, labels = as.expression(lapply(lbs, 
+                      function(x) bquote(bold(.(x))))), cex = fsize, 
+                      adj = 0.5, col = fcol)
+                  }
+                  else if (isTRUE(fstyle == "bolditalic") == 
+                    TRUE) {
+                    graphics::text(ndss, labels = as.expression(lapply(lbs, 
+                      function(x) bquote(bolditalic(.(x))))), 
+                      cex = fsize, adj = 0.5, col = fcol)
+                  }
+                }
             }
             else {
-                graphics::text(ndss, lbs, cex = tcex, pos = pos, 
-                  col = tcol, offset = (cex/4L), adj = c(0.5, 
-                    1))
+                if (missing(fstyle) == TRUE || (missing(fstyle) == 
+                  FALSE && isTRUE(fstyle %in% c("italic", "bold", 
+                  "bolditalic") == FALSE))) {
+                  graphics::text(ndss, lbs, cex = fsize, pos = pos, 
+                    col = fcol, offset = (cex/4L), adj = c(0.5, 
+                      1))
+                }
+                else if (missing(fstyle) == FALSE) {
+                  if (isTRUE(fstyle == "italic") == TRUE) {
+                    graphics::text(ndss, as.expression(lapply(lbs, 
+                      function(x) bquote(italic(.(x))))), cex = fsize, 
+                      pos = pos, col = fcol, offset = (cex/4L), 
+                      adj = c(0.5, 1))
+                  }
+                  else if (isTRUE(fstyle == "bold") == TRUE) {
+                    graphics::text(ndss, as.expression(lapply(lbs, 
+                      function(x) bquote(bold(.(x))))), cex = fsize, 
+                      pos = pos, col = fcol, offset = (cex/4L), 
+                      adj = c(0.5, 1))
+                  }
+                  else if (isTRUE(fstyle == "bolditalic") == 
+                    TRUE) {
+                    graphics::text(ndss, as.expression(lapply(lbs, 
+                      function(x) bquote(bolditalic(.(x))))), 
+                      cex = fsize, pos = pos, col = fcol, offset = (cex/4L), 
+                      adj = c(0.5, 1))
+                  }
+                }
             }
         }
         else if (isTRUE(length(pos) == n) == TRUE) {
-            graphics::text(ndss, lbs, cex = tcex, pos = pos, 
-                col = tcol[1], offset = (cex/4L), adj = c(0.5, 
-                  1))
+            if (missing(fstyle) == TRUE || (missing(fstyle) == 
+                FALSE && isTRUE(fstyle %in% c("italic", "bold", 
+                "bolditalic") == FALSE))) {
+                graphics::text(ndss, lbs, cex = fsize, pos = pos, 
+                  col = fcol[1], offset = (cex/4L), adj = c(0.5, 
+                    1))
+            }
+            else if (missing(fstyle) == FALSE) {
+                if (isTRUE(fstyle == "italic") == TRUE) {
+                  graphics::text(ndss, as.expression(lapply(lbs, 
+                    function(x) bquote(italic(.(x))))), cex = fsize, 
+                    pos = pos, col = fcol[1], offset = (cex/4L), 
+                    adj = c(0.5, 1))
+                }
+                else if (isTRUE(fstyle == "bold") == TRUE) {
+                  graphics::text(ndss, as.expression(lapply(lbs, 
+                    function(x) bquote(bold(.(x))))), cex = fsize, 
+                    pos = pos, col = fcol[1], offset = (cex/4L), 
+                    adj = c(0.5, 1))
+                }
+                else if (isTRUE(fstyle == "bolditalic") == TRUE) {
+                  graphics::text(ndss, as.expression(lapply(lbs, 
+                    function(x) bquote(bolditalic(.(x))))), cex = fsize, 
+                    pos = pos, col = fcol[1], offset = (cex/4L), 
+                    adj = c(0.5, 1))
+                }
+            }
         }
         else {
             if (isTRUE(pos[1] == 0) == TRUE) {
-                graphics::text(ndss, labels = lbs, cex = tcex, 
-                  adj = 0.5, col = tcol)
+                if (missing(fstyle) == TRUE || (missing(fstyle) == 
+                  FALSE && isTRUE(fstyle %in% c("italic", "bold", 
+                  "bolditalic") == FALSE))) {
+                  graphics::text(ndss, labels = lbs, cex = fsize, 
+                    adj = 0.5, col = fcol)
+                }
+                else if (missing(fstyle) == FALSE) {
+                  if (isTRUE(fstyle == "italic") == TRUE) {
+                    graphics::text(ndss, labels = as.expression(lapply(lbs, 
+                      function(x) bquote(italic(.(x))))), cex = fsize, 
+                      adj = 0.5, col = fcol)
+                  }
+                  else if (isTRUE(fstyle == "bold") == TRUE) {
+                    graphics::text(ndss, labels = as.expression(lapply(lbs, 
+                      function(x) bquote(bold(.(x))))), cex = fsize, 
+                      adj = 0.5, col = fcol)
+                  }
+                  else if (isTRUE(fstyle == "bolditalic") == 
+                    TRUE) {
+                    graphics::text(ndss, labels = as.expression(lapply(lbs, 
+                      function(x) bquote(bolditalic(.(x))))), 
+                      cex = fsize, adj = 0.5, col = fcol)
+                  }
+                }
             }
             else {
-                graphics::text(ndss, lbs, cex = tcex, pos = pos[1], 
-                  col = tcol, offset = (cex/4L), adj = c(0.5, 
-                    1))
+                if (missing(fstyle) == TRUE || (missing(fstyle) == 
+                  FALSE && isTRUE(fstyle %in% c("italic", "bold", 
+                  "bolditalic") == FALSE))) {
+                  graphics::text(ndss, lbs, cex = fsize, pos = pos[1], 
+                    col = fcol, offset = (cex/4L), adj = c(0.5, 
+                      1))
+                }
+                else if (missing(fstyle) == FALSE) {
+                  if (isTRUE(fstyle == "italic") == TRUE) {
+                    graphics::text(ndss, as.expression(lapply(lbs, 
+                      function(x) bquote(italic(.(x))))), cex = fsize, 
+                      pos = pos[1], col = fcol, offset = (cex/4L), 
+                      adj = c(0.5, 1))
+                  }
+                  else if (isTRUE(fstyle == "bold") == TRUE) {
+                    graphics::text(ndss, as.expression(lapply(lbs, 
+                      function(x) bquote(bold(.(x))))), cex = fsize, 
+                      pos = pos[1], col = fcol, offset = (cex/4L), 
+                      adj = c(0.5, 1))
+                  }
+                  else if (isTRUE(fstyle == "bolditalic") == 
+                    TRUE) {
+                    graphics::text(ndss, as.expression(lapply(lbs, 
+                      function(x) bquote(bolditalic(.(x))))), 
+                      cex = fsize, pos = pos[1], col = fcol, 
+                      offset = (cex/4L), adj = c(0.5, 1))
+                  }
+                }
             }
         }
     }
@@ -1142,17 +1410,18 @@ function (net, layout = c("circ", "force", "stress", "conc",
             }
         }
         if (isTRUE(flgcx == FALSE) == TRUE) {
-            graphics::text(ndss, labels = atts, cex = tcex, pos = pos%%4 + 
-                1L, col = tcol, offset = (cex/4L), adj = c(0.5, 
-                1))
+            graphics::text(ndss, labels = atts, cex = fsize, 
+                pos = pos%%4 + 1L, col = fcol, offset = (cex/4L), 
+                adj = c(0.5, 1))
         }
         else if (isTRUE(flgcx == TRUE) == TRUE) {
-            graphics::text(ndss, labels = atts, cex = tcex, pos = pos%%4 + 
-                1L, col = tcol, offset = (min(cex)/4L), adj = c(0.5, 
-                1))
+            graphics::text(ndss, labels = atts, cex = fsize, 
+                pos = pos%%4 + 1L, col = fcol, offset = (min(cex)/4L), 
+                adj = c(0.5, 1))
         }
     }
-    graphics::par(mar = opm)
+    graphics::par(mar = omr)
     graphics::par(bg = obg)
     graphics::par(lend = 0)
+    graphics::par(mai = omi)
 }
